var group__libopenmpt__c =
[
    [ "Render param indices", "group__openmpt__module__render__param.html", "group__openmpt__module__render__param" ],
    [ "Pattern cell indices", "group__openmpt__module__command__index.html", "group__openmpt__module__command__index" ],
    [ "openmpt_stream_callbacks", "structopenmpt__stream__callbacks.html", [
      [ "read", "structopenmpt__stream__callbacks.html#a1ebf210f90c37ea1bb3ff0342039d8ae", null ],
      [ "seek", "structopenmpt__stream__callbacks.html#ac5e9f267a786ab8f4334e4e2663af6e9", null ],
      [ "tell", "structopenmpt__stream__callbacks.html#aff46dc3277047eafb6b3b04fbcdd85c5", null ]
    ] ],
    [ "openmpt_module_initial_ctl", "structopenmpt__module__initial__ctl.html", [
      [ "ctl", "structopenmpt__module__initial__ctl.html#a085cbbbe2b15ab763fcb20f0bdcfe5e8", null ],
      [ "value", "structopenmpt__module__initial__ctl.html#a11fbe4f662ac10d8deaad8891a88ddbb", null ]
    ] ],
    [ "openmpt_stream_buffer", "structopenmpt__stream__buffer.html", [
      [ "file_data", "structopenmpt__stream__buffer.html#ae3e4597d5b13ded13241786e231fbd8d", null ],
      [ "file_pos", "structopenmpt__stream__buffer.html#a65ad826a7f9401ded375bdba8fd19b94", null ],
      [ "file_size", "structopenmpt__stream__buffer.html#a1293c6a2af000f1ba1709775969b5fc8", null ],
      [ "overflow", "structopenmpt__stream__buffer.html#a2a71b5fe812cbb7ee52d6daaf2b606ac", null ],
      [ "prefix_size", "structopenmpt__stream__buffer.html#a062bba0e60c5766852bc22d1f5e4f148", null ]
    ] ],
    [ "LIBOPENMPT_STREAM_CALLBACKS_BUFFER", "group__libopenmpt__c.html#gafe56244a9a28dc71e6b48d5fb006aa9a", null ],
    [ "LIBOPENMPT_STREAM_CALLBACKS_FD", "group__libopenmpt__c.html#ga487b51694e4cf74a9727baf802380b53", null ],
    [ "LIBOPENMPT_STREAM_CALLBACKS_FILE", "group__libopenmpt__c.html#ga81b35d4ef8a335cc32e3cd605071cb0e", null ],
    [ "OPENMPT_ERROR_ARGUMENT_NULL_POINTER", "group__libopenmpt__c.html#ga4cf4b85e2b59b7e58c768791782a9657", null ],
    [ "OPENMPT_ERROR_BASE", "group__libopenmpt__c.html#gaa0d7b531f0841d8cb8d264005d0328da", null ],
    [ "OPENMPT_ERROR_DOMAIN", "group__libopenmpt__c.html#ga8ce40b6e5bebc76e080c3df197bf8839", null ],
    [ "OPENMPT_ERROR_EXCEPTION", "group__libopenmpt__c.html#ga57a346d0443f50df673ef9d5119b3c76", null ],
    [ "OPENMPT_ERROR_FUNC_RESULT_DEFAULT", "group__libopenmpt__c.html#ga1143a4ab0a1a0554f4f8de70b3737e7b", null ],
    [ "OPENMPT_ERROR_FUNC_RESULT_LOG", "group__libopenmpt__c.html#ga7bde366976a385ccb8711322d610c046", null ],
    [ "OPENMPT_ERROR_FUNC_RESULT_NONE", "group__libopenmpt__c.html#ga12f6bd63553a677c95306c6ca9b399fd", null ],
    [ "OPENMPT_ERROR_FUNC_RESULT_STORE", "group__libopenmpt__c.html#gae4ebebf8546b5a94a2ec45c694ce9923", null ],
    [ "OPENMPT_ERROR_GENERAL", "group__libopenmpt__c.html#gaea002e826ecc42e0bcdcc07eb1340044", null ],
    [ "OPENMPT_ERROR_INVALID_ARGUMENT", "group__libopenmpt__c.html#ga4d8caa2383f145fee70c7e97c3d2ffcc", null ],
    [ "OPENMPT_ERROR_INVALID_MODULE_POINTER", "group__libopenmpt__c.html#ga789b4493a0ee3a3a6d145561bbbc2b97", null ],
    [ "OPENMPT_ERROR_LENGTH", "group__libopenmpt__c.html#gad36da61e75bfb856174969636fa9a6f3", null ],
    [ "OPENMPT_ERROR_LOGIC", "group__libopenmpt__c.html#gae183d049e057202eba8873f9a1c6b813", null ],
    [ "OPENMPT_ERROR_OK", "group__libopenmpt__c.html#ga3316f26904f1e569386855b229d46d5f", null ],
    [ "OPENMPT_ERROR_OUT_OF_MEMORY", "group__libopenmpt__c.html#ga8e0227f30332ba3a0b4cc1d6a330c2de", null ],
    [ "OPENMPT_ERROR_OUT_OF_RANGE", "group__libopenmpt__c.html#gac2427d08b6fdd62376ca813543f91c9a", null ],
    [ "OPENMPT_ERROR_OVERFLOW", "group__libopenmpt__c.html#ga1b887f2a7b8a6c9eb0a5ac1c3958d84f", null ],
    [ "OPENMPT_ERROR_RANGE", "group__libopenmpt__c.html#gaff98a6ffecc468bd650b151c97fdc181", null ],
    [ "OPENMPT_ERROR_RUNTIME", "group__libopenmpt__c.html#gaa739aee88cf80f57b9db1dd0bd57b356", null ],
    [ "OPENMPT_ERROR_UNDERFLOW", "group__libopenmpt__c.html#ga9c185e78e8429d68c452eb187cf37151", null ],
    [ "OPENMPT_ERROR_UNKNOWN", "group__libopenmpt__c.html#ga598311177f2b9ca335092ecb84b3dbf7", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_FLAGS_CONTAINERS", "group__libopenmpt__c.html#ga680c710bbbf3f23548f070335761b737", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_FLAGS_DEFAULT", "group__libopenmpt__c.html#ga6dc1e808a26084ffec15e3b159a22c0f", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_FLAGS_MODULES", "group__libopenmpt__c.html#gad4e86a00ec4879f9d654e11ac49fa768", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_FLAGS_NONE", "group__libopenmpt__c.html#ga460291a7317358ce952fb202edc8a9eb", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_RESULT_ERROR", "group__libopenmpt__c.html#gab4eedfb884356f25118f8782f088272e", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_RESULT_FAILURE", "group__libopenmpt__c.html#gad5bb8ddad658475f594e407c6366c25f", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_RESULT_SUCCESS", "group__libopenmpt__c.html#ga5bf3273a05d37074f8c64b0354a2d9d4", null ],
    [ "OPENMPT_PROBE_FILE_HEADER_RESULT_WANTMOREDATA", "group__libopenmpt__c.html#ga0dc4c06017ba990e69aab521a0e14248", null ],
    [ "openmpt_stream_buffer_init_prefix_only", "group__libopenmpt__c.html#gaa74ca2c46b5f904f38adb928ca654173", null ],
    [ "openmpt_stream_buffer_overflowed", "group__libopenmpt__c.html#ga7b9523114368368950872b6235fe184c", null ],
    [ "OPENMPT_STREAM_SEEK_CUR", "group__libopenmpt__c.html#ga3a3073e046099101d80fca52bfb4c154", null ],
    [ "OPENMPT_STREAM_SEEK_END", "group__libopenmpt__c.html#gaba2d3014fed47caf598bb47b20acaee6", null ],
    [ "OPENMPT_STREAM_SEEK_SET", "group__libopenmpt__c.html#ga186d096037bbb5c4b7c973fbabe02bdd", null ],
    [ "OPENMPT_STRING_BUILD", "group__libopenmpt__c.html#gad1db14545f64d123d1727026db01bdb3", null ],
    [ "OPENMPT_STRING_CONTACT", "group__libopenmpt__c.html#ga8109c9c05bb3156183f1eead45a0cd13", null ],
    [ "OPENMPT_STRING_CORE_VERSION", "group__libopenmpt__c.html#ga1e7f086fbab36f31adf47735dc3ec2c0", null ],
    [ "OPENMPT_STRING_CREDITS", "group__libopenmpt__c.html#gac072d974496c651c863b3a5f4baae0d1", null ],
    [ "OPENMPT_STRING_LIBRARY_FEATURES", "group__libopenmpt__c.html#ga4095a6af34e59487162bf581d6943866", null ],
    [ "OPENMPT_STRING_LIBRARY_VERSION", "group__libopenmpt__c.html#gadc9d6e523b44b9b4240893f3c56c3498", null ],
    [ "OPENMPT_STRING_LICENSE", "group__libopenmpt__c.html#gabd51630ad7af65f5fe71647446a241ed", null ],
    [ "openmpt_error_func", "group__libopenmpt__c.html#gaa68155b220861de6218bc6b599071f21", null ],
    [ "openmpt_log_func", "group__libopenmpt__c.html#gaeec3c004981950af696bfd2688e250b2", null ],
    [ "openmpt_module", "group__libopenmpt__c.html#gadb90c01fba5864c0359a28c2d4151dd7", null ],
    [ "openmpt_module_initial_ctl", "group__libopenmpt__c.html#gac5daa1e631884cf990a326442a55f98a", null ],
    [ "openmpt_stream_buffer", "group__libopenmpt__c.html#ga7299bdb1270ac987339a5bab822a3973", null ],
    [ "openmpt_stream_callbacks", "group__libopenmpt__c.html#gab7032a4db4a21f5b0ef8bd0ba53442e1", null ],
    [ "openmpt_stream_read_func", "group__libopenmpt__c.html#gaeccd341852695cc71d8a5e3ac47ff168", null ],
    [ "openmpt_stream_seek_func", "group__libopenmpt__c.html#ga88bc398e2fedc565ef8747bf49abdae5", null ],
    [ "openmpt_stream_tell_func", "group__libopenmpt__c.html#gaf5b929ef6551750bb10acf4a2fadc341", null ],
    [ "openmpt_could_open_probability", "group__libopenmpt__c.html#ga281464dbc5cd791126eed6f819b0171e", null ],
    [ "openmpt_could_open_probability2", "group__libopenmpt__c.html#ga33393fb514f79e4ced5a0a5fdebfb5e3", null ],
    [ "openmpt_could_open_propability", "group__libopenmpt__c.html#ga6b636df734a1caa154886ae0ceb33ad7", null ],
    [ "openmpt_error_func_default", "group__libopenmpt__c.html#ga5d8d28ab0eef88f82c7ffbd28c39f361", null ],
    [ "openmpt_error_func_errno", "group__libopenmpt__c.html#ga2bde048f9e17516ac7c1166746abb1fc", null ],
    [ "openmpt_error_func_errno_userdata", "group__libopenmpt__c.html#gaa52dec68957368f49dbcc9cd6603dadc", null ],
    [ "openmpt_error_func_ignore", "group__libopenmpt__c.html#ga0e251d4cd88cde1b7e79d4024b154a8e", null ],
    [ "openmpt_error_func_log", "group__libopenmpt__c.html#ga8dfe5edd28c6590c98eaeaa93e81a625", null ],
    [ "openmpt_error_func_store", "group__libopenmpt__c.html#gaff878452d42b028d3c764794524f07cc", null ],
    [ "openmpt_error_is_transient", "group__libopenmpt__c.html#ga1e034f3145ab44065e022203e03f1f35", null ],
    [ "openmpt_error_string", "group__libopenmpt__c.html#gaaf339f2d1db4afe7042e7976cd34dd22", null ],
    [ "openmpt_free_string", "group__libopenmpt__c.html#ga0fb70a57725fc29499c557974f16a873", null ],
    [ "openmpt_get_core_version", "group__libopenmpt__c.html#gae10ab2bd98577a7023a211807889bd07", null ],
    [ "openmpt_get_library_version", "group__libopenmpt__c.html#gac53f78258568ddfb07be07ec33b1b9b6", null ],
    [ "openmpt_get_string", "group__libopenmpt__c.html#ga8ae1e912761e09f398f16d9f347248ca", null ],
    [ "openmpt_get_supported_extensions", "group__libopenmpt__c.html#ga6fff8e3cf426e01e6434d084233c43c5", null ],
    [ "openmpt_is_extension_supported", "group__libopenmpt__c.html#ga7a5f19f790dad4ab9deb62d4f4e6bbc4", null ],
    [ "openmpt_log_func_default", "group__libopenmpt__c.html#ga67648b980fac7134b5ac124d934d5750", null ],
    [ "openmpt_log_func_silent", "group__libopenmpt__c.html#ga3d83925bb2083e25515a79a48321a4ce", null ],
    [ "openmpt_module_create", "group__libopenmpt__c.html#ga4552be0a5fe6dbc25fe195d1586cb79f", null ],
    [ "openmpt_module_create2", "group__libopenmpt__c.html#ga1c92733a25f1c01c2cda2528ccc4e415", null ],
    [ "openmpt_module_create_from_memory", "group__libopenmpt__c.html#ga53377a365f001a99ae4626918e55b25e", null ],
    [ "openmpt_module_create_from_memory2", "group__libopenmpt__c.html#ga8237a4d9dfb0f33c7cd0a2926f30a25f", null ],
    [ "openmpt_module_ctl_get", "group__libopenmpt__c.html#ga20d871022840893e6f4cb13ad78a0ff7", null ],
    [ "openmpt_module_ctl_get_boolean", "group__libopenmpt__c.html#ga79c1fc512437220d9f65556723326c78", null ],
    [ "openmpt_module_ctl_get_floatingpoint", "group__libopenmpt__c.html#gac6e1f6ec3d9cc82fa3df5e63dc5b5350", null ],
    [ "openmpt_module_ctl_get_integer", "group__libopenmpt__c.html#gab4cd78a172569a5d02c4e41c3caac18c", null ],
    [ "openmpt_module_ctl_get_text", "group__libopenmpt__c.html#ga13b040e57fd61854766b3d3fdca14b3a", null ],
    [ "openmpt_module_ctl_set", "group__libopenmpt__c.html#ga384de8fb7266821e7a3677460861593e", null ],
    [ "openmpt_module_ctl_set_boolean", "group__libopenmpt__c.html#gab178566ca8e2280f4389370200b00ad5", null ],
    [ "openmpt_module_ctl_set_floatingpoint", "group__libopenmpt__c.html#ga7af8284475e3411b25d3f8c9686b02e6", null ],
    [ "openmpt_module_ctl_set_integer", "group__libopenmpt__c.html#ga6a3990be4d7140e255fbc96e1eaed3db", null ],
    [ "openmpt_module_ctl_set_text", "group__libopenmpt__c.html#ga8a4b646f940bd9e9527dbda4edbeca17", null ],
    [ "openmpt_module_destroy", "group__libopenmpt__c.html#ga40d27bb0ef054c3cd5e7ae3e85ed64e1", null ],
    [ "openmpt_module_error_clear", "group__libopenmpt__c.html#gaceaa2675b539674c1611d1e8a392aa87", null ],
    [ "openmpt_module_error_get_last", "group__libopenmpt__c.html#ga7ffc363899565eebe05d38a670050c83", null ],
    [ "openmpt_module_error_get_last_message", "group__libopenmpt__c.html#ga026a8746a423af3747f9f61998594e15", null ],
    [ "openmpt_module_error_set_last", "group__libopenmpt__c.html#ga80114288acfa1d1ae2bfdff571545c47", null ],
    [ "openmpt_module_format_pattern_row_channel", "group__libopenmpt__c.html#gad031f518dd6bcbcd86daaacd1a3a97f2", null ],
    [ "openmpt_module_format_pattern_row_channel_command", "group__libopenmpt__c.html#ga13c81dffe7c50db41826a4da28713f9b", null ],
    [ "openmpt_module_get_channel_name", "group__libopenmpt__c.html#ga35b34623ad43234f71b2fc6f1bdc67ac", null ],
    [ "openmpt_module_get_ctls", "group__libopenmpt__c.html#ga9a7a95ee4073243b1193120c9107ce99", null ],
    [ "openmpt_module_get_current_channel_vu_left", "group__libopenmpt__c.html#ga2fdc099414e6be2172ab43a41628937a", null ],
    [ "openmpt_module_get_current_channel_vu_mono", "group__libopenmpt__c.html#ga498bd8b7f699671ef573522cf908bc65", null ],
    [ "openmpt_module_get_current_channel_vu_rear_left", "group__libopenmpt__c.html#ga3c5d64718d0d574bf94bd9f13aa3b8a1", null ],
    [ "openmpt_module_get_current_channel_vu_rear_right", "group__libopenmpt__c.html#ga459facd9def73d056190a76882da29b6", null ],
    [ "openmpt_module_get_current_channel_vu_right", "group__libopenmpt__c.html#gab90660d5d9fa932cfff118023c4b56c8", null ],
    [ "openmpt_module_get_current_estimated_bpm", "group__libopenmpt__c.html#gae3ed09be74bd9e5dc78d424608a17e72", null ],
    [ "openmpt_module_get_current_order", "group__libopenmpt__c.html#ga88bd245db9a3e857443920bf68f093a6", null ],
    [ "openmpt_module_get_current_pattern", "group__libopenmpt__c.html#ga9f2013da0ddda5888d8ac9821193c269", null ],
    [ "openmpt_module_get_current_playing_channels", "group__libopenmpt__c.html#ga145570605cff14c147d096e93bd16dbc", null ],
    [ "openmpt_module_get_current_row", "group__libopenmpt__c.html#ga18079a93aa8ed0452718ed88ad8942be", null ],
    [ "openmpt_module_get_current_speed", "group__libopenmpt__c.html#ga3e6e38f688443cb9d002626a1516dcfd", null ],
    [ "openmpt_module_get_current_tempo", "group__libopenmpt__c.html#gab00cde7c1a2b17ebbecd677bd2e7c281", null ],
    [ "openmpt_module_get_duration_seconds", "group__libopenmpt__c.html#ga3d243ff23a128ac52e8148343c52618f", null ],
    [ "openmpt_module_get_instrument_name", "group__libopenmpt__c.html#ga6fad3256eb4123f930d519fc74e01d73", null ],
    [ "openmpt_module_get_metadata", "group__libopenmpt__c.html#gac171f8fb2c7a0b998855956069159068", null ],
    [ "openmpt_module_get_metadata_keys", "group__libopenmpt__c.html#ga79ab73081485c4bd8cdf80e638003893", null ],
    [ "openmpt_module_get_num_channels", "group__libopenmpt__c.html#ga1a511e81ccada3f70aebd0854ae9c2d9", null ],
    [ "openmpt_module_get_num_instruments", "group__libopenmpt__c.html#ga0d557f95d21d8cdaadbc35f0d5e2be60", null ],
    [ "openmpt_module_get_num_orders", "group__libopenmpt__c.html#ga8ad3c291b61619556556bb991f3b62f8", null ],
    [ "openmpt_module_get_num_patterns", "group__libopenmpt__c.html#gae8fa17a20133ebc64a26305aa181cc4c", null ],
    [ "openmpt_module_get_num_samples", "group__libopenmpt__c.html#gaadd84c34e34a322dd645df68923c7fe5", null ],
    [ "openmpt_module_get_num_subsongs", "group__libopenmpt__c.html#ga41be89e94d250be0941b4eb56e56c1c8", null ],
    [ "openmpt_module_get_order_name", "group__libopenmpt__c.html#ga071d326f349e97d6728d77fc1402099f", null ],
    [ "openmpt_module_get_order_pattern", "group__libopenmpt__c.html#ga46159826ab2854615c9872dd6eb61256", null ],
    [ "openmpt_module_get_pattern_name", "group__libopenmpt__c.html#gaa4a2d323f4052c89f1d75013cdf35eb4", null ],
    [ "openmpt_module_get_pattern_num_rows", "group__libopenmpt__c.html#ga8e1a6c3ad88b325825a4ec046500f322", null ],
    [ "openmpt_module_get_pattern_row_channel_command", "group__libopenmpt__c.html#ga0daf4f417af31c67f5e514ec67a60cde", null ],
    [ "openmpt_module_get_position_seconds", "group__libopenmpt__c.html#ga9507836c6d63771742d570919d417533", null ],
    [ "openmpt_module_get_render_param", "group__libopenmpt__c.html#ga7620687f3681690616dffe8d356f9df9", null ],
    [ "openmpt_module_get_repeat_count", "group__libopenmpt__c.html#ga25c205297bb4c001b341e000fd6d0820", null ],
    [ "openmpt_module_get_sample_name", "group__libopenmpt__c.html#gaf33b4ab4ad556ea3d654c04e6454d510", null ],
    [ "openmpt_module_get_selected_subsong", "group__libopenmpt__c.html#gad0ca32c54b27090e08005ccbb9477d3c", null ],
    [ "openmpt_module_get_subsong_name", "group__libopenmpt__c.html#gafd8716078c53af4bb761016e9c7477a1", null ],
    [ "openmpt_module_highlight_pattern_row_channel", "group__libopenmpt__c.html#gadbfc90800a26de5330b47ee137ba7f7d", null ],
    [ "openmpt_module_highlight_pattern_row_channel_command", "group__libopenmpt__c.html#ga9d6981fa546cf4e5553f93d81b0f332f", null ],
    [ "openmpt_module_read_float_mono", "group__libopenmpt__c.html#ga59437852eaaf2630813eb07edeb83aca", null ],
    [ "openmpt_module_read_float_quad", "group__libopenmpt__c.html#ga28cfbb80190e5b4ddabc5975a47384ce", null ],
    [ "openmpt_module_read_float_stereo", "group__libopenmpt__c.html#gac310145e86bd88d5f38f3168073014fc", null ],
    [ "openmpt_module_read_interleaved_float_quad", "group__libopenmpt__c.html#ga7ff2eac8523bb05b39b541ab21f02f2e", null ],
    [ "openmpt_module_read_interleaved_float_stereo", "group__libopenmpt__c.html#ga036901606728ce00d9f104adca6a5c09", null ],
    [ "openmpt_module_read_interleaved_quad", "group__libopenmpt__c.html#ga4be8b5fad0607953cc760ca739ac3cb9", null ],
    [ "openmpt_module_read_interleaved_stereo", "group__libopenmpt__c.html#gac8331183f8a0a453f0fbdc4791fd79cb", null ],
    [ "openmpt_module_read_mono", "group__libopenmpt__c.html#gabb9d640ef27e3c289a88831a4ad28c7e", null ],
    [ "openmpt_module_read_quad", "group__libopenmpt__c.html#gae2d0b54c815605e7f86d32e49bb8befc", null ],
    [ "openmpt_module_read_stereo", "group__libopenmpt__c.html#ga8e2766307479bcef46464d8bb2b957a6", null ],
    [ "openmpt_module_select_subsong", "group__libopenmpt__c.html#ga523fe9d172709472049941899c9835f2", null ],
    [ "openmpt_module_set_error_func", "group__libopenmpt__c.html#gaed6b9e12835aa9d17713eb1d8e8bed3b", null ],
    [ "openmpt_module_set_log_func", "group__libopenmpt__c.html#ga2b9002a91ab97038c67d95abbc973de4", null ],
    [ "openmpt_module_set_position_order_row", "group__libopenmpt__c.html#gac4e234c38901822134feb37721ada825", null ],
    [ "openmpt_module_set_position_seconds", "group__libopenmpt__c.html#ga43b63d715b1a8b287d6b4ef1708fbc93", null ],
    [ "openmpt_module_set_render_param", "group__libopenmpt__c.html#gaecd0bb67bb3b720340bb12f5df86db2a", null ],
    [ "openmpt_module_set_repeat_count", "group__libopenmpt__c.html#gaad2167f7a943f630a72af9b57a586491", null ],
    [ "openmpt_probe_file_header", "group__libopenmpt__c.html#gaac34f4d87dd3c3e59b12daac81935d6c", null ],
    [ "openmpt_probe_file_header_from_stream", "group__libopenmpt__c.html#ga52ee99cdabedc1953682e347e5f77afb", null ],
    [ "openmpt_probe_file_header_get_recommended_size", "group__libopenmpt__c.html#gaf5860bba2af2c4b02b8daa4539216f1a", null ],
    [ "openmpt_probe_file_header_without_filesize", "group__libopenmpt__c.html#ga92cdc66eb529a8a4a67987b659ed3c5e", null ],
    [ "openmpt_stream_buffer_init", "group__libopenmpt__c.html#ga527b70571e44f6c4f0066d4a10670da4", null ],
    [ "openmpt_stream_buffer_read_func", "group__libopenmpt__c.html#gae95f26d25828cd5c46e7a3b7d556b9f4", null ],
    [ "openmpt_stream_buffer_seek_func", "group__libopenmpt__c.html#gacc76d42781b233ba4717dcf0dc415eec", null ],
    [ "openmpt_stream_buffer_tell_func", "group__libopenmpt__c.html#ga9101861fab39cd6993b206dc0270e6c5", null ],
    [ "openmpt_stream_fd_read_func", "group__libopenmpt__c.html#ga534305a50c22c68f4eb4735ac6e271db", null ],
    [ "openmpt_stream_file_read_func", "group__libopenmpt__c.html#gab35f4ca3b71e20cabdc2febb5d48db87", null ],
    [ "openmpt_stream_file_seek_func", "group__libopenmpt__c.html#ga53dd106d28a4b68eea86fba6bfdd1b9a", null ],
    [ "openmpt_stream_file_tell_func", "group__libopenmpt__c.html#gaecc775ac3096e1a1060941e0ef8ee0ec", null ],
    [ "openmpt_stream_get_buffer_callbacks", "group__libopenmpt__c.html#gaacc6e056e2161e64184079e0f23d34b0", null ],
    [ "openmpt_stream_get_fd_callbacks", "group__libopenmpt__c.html#ga9b222cad5195de39b84503c089eca611", null ],
    [ "openmpt_stream_get_file_callbacks", "group__libopenmpt__c.html#gac89b0366fe1f3686bcff1be86b69c79a", null ]
];